[gtk+/wip/otte/icon-size: 16/20] enums: Change GtkIconSize values



commit 1992ab06a8971ddfe6b9e5061780784f30b96d12
Author: Benjamin Otte <otte redhat com>
Date:   Tue Jan 24 06:52:04 2017 +0100

    enums: Change GtkIconSize values
    
    The new values are the ones we intend to keep. The old ones had
    duplicated meanings and nobody knew which one to take.

 demos/gtk-demo/clipboard.c                     |    2 +-
 demos/gtk-demo/dialog.c                        |    2 +-
 demos/gtk-demo/font-features.ui                |   44 ------------------------
 demos/gtk-demo/gtkfishbowl.c                   |    2 +-
 demos/gtk-demo/images.c                        |    4 +-
 demos/gtk-demo/listbox.c                       |    2 +-
 demos/gtk-demo/revealer.ui                     |   18 +++++-----
 demos/gtk-demo/toolpalette.c                   |    2 +-
 demos/icon-browser/window.ui                   |    1 -
 demos/widget-factory/widget-factory.ui         |    2 -
 docs/tools/widgets.c                           |    2 +-
 examples/application10/window.ui               |    1 -
 examples/application7/window.ui                |    1 -
 examples/application8/window.ui                |    1 -
 examples/application9/window.ui                |    1 -
 gtk/gtkcellrendererpixbuf.c                    |    4 +-
 gtk/gtkcellrendererspinner.c                   |    4 +-
 gtk/gtkentry.c                                 |    2 -
 gtk/gtkenums.h                                 |   25 +++++--------
 gtk/gtkiconhelper.c                            |    8 ++--
 gtk/gtkicontheme.c                             |   38 +++------------------
 gtk/gtkiconthemeprivate.h                      |    1 +
 gtk/gtkimage.c                                 |    4 +-
 gtk/gtkmountoperation.c                        |    2 +-
 gtk/gtkprintbackend.c                          |    2 +-
 gtk/gtkprintunixdialog.c                       |    2 +-
 gtk/gtkrecentchooserdefault.c                  |   12 ++-----
 gtk/gtktoolbutton.c                            |    9 +----
 gtk/inspector/general.ui                       |    2 -
 gtk/inspector/misc-info.ui                     |    5 ---
 gtk/ui/gtkfilechooserbutton.ui                 |    1 -
 gtk/ui/gtkpagesetupunixdialog.ui               |    4 --
 gtk/ui/gtkpathbar.ui                           |    2 -
 gtk/ui/gtkplacesviewrow.ui                     |    1 -
 gtk/ui/gtkprintunixdialog.ui                   |    1 -
 gtk/ui/gtksearchbar.ui                         |    1 -
 tests/dialog.ui                                |    1 -
 tests/selectionmode.ui                         |    3 --
 tests/testdialog.c                             |    2 +-
 tests/testdnd2.c                               |    6 ++--
 tests/testflowbox.c                            |    2 +-
 tests/testgiconpixbuf.c                        |    4 +-
 tests/testimage.c                              |    8 ++--
 tests/testnotebookdnd.c                        |   17 ++-------
 tests/testtoolbar.c                            |    2 +-
 tests/testverticalcells.c                      |    2 +-
 tests/visuals/osd-toolbars.ui                  |    8 ----
 testsuite/reftests/gtk-icontheme-sizing.ref.ui |    1 -
 testsuite/reftests/icon-vfuncs.ui              |    1 -
 testsuite/reftests/iconview-empty.ref.ui       |   16 ---------
 50 files changed, 66 insertions(+), 222 deletions(-)
---
diff --git a/demos/gtk-demo/clipboard.c b/demos/gtk-demo/clipboard.c
index 04d80c2..308b36e 100644
--- a/demos/gtk-demo/clipboard.c
+++ b/demos/gtk-demo/clipboard.c
@@ -78,7 +78,7 @@ get_image_pixbuf (GtkImage *image)
     case GTK_IMAGE_ICON_NAME:
       icon_name = gtk_image_get_icon_name (image);
       icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (image)));
-      gtk_icon_size_lookup (GTK_ICON_SIZE_BUTTON, &width, NULL);
+      gtk_icon_size_lookup (GTK_ICON_SIZE_INHERIT, &width, NULL);
       return gtk_icon_theme_load_icon (icon_theme,
                                        icon_name,
                                        width,
diff --git a/demos/gtk-demo/dialog.c b/demos/gtk-demo/dialog.c
index f28805a..d75a45e 100644
--- a/demos/gtk-demo/dialog.c
+++ b/demos/gtk-demo/dialog.c
@@ -59,7 +59,7 @@ interactive_dialog_clicked (GtkButton *button,
   gtk_box_pack_start (GTK_BOX (content_area), hbox, FALSE, FALSE);
 
   image = gtk_image_new_from_icon_name ("dialog-question");
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE);
 
   table = gtk_grid_new ();
diff --git a/demos/gtk-demo/font-features.ui b/demos/gtk-demo/font-features.ui
index 3906b8c..d05e4b5 100644
--- a/demos/gtk-demo/font-features.ui
+++ b/demos/gtk-demo/font-features.ui
@@ -84,7 +84,6 @@
                                   <object class="GtkImage" id="kern_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -137,7 +136,6 @@
                                   <object class="GtkImage" id="liga_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -169,7 +167,6 @@
                                   <object class="GtkImage" id="dlig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -201,7 +198,6 @@
                                   <object class="GtkImage" id="hlig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -233,7 +229,6 @@
                                   <object class="GtkImage" id="clig_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -286,7 +281,6 @@
                                   <object class="GtkImage" id="smcp_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -318,7 +312,6 @@
                                   <object class="GtkImage" id="c2sc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -350,7 +343,6 @@
                                   <object class="GtkImage" id="pcap_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -382,7 +374,6 @@
                                   <object class="GtkImage" id="c2pc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -414,7 +405,6 @@
                                   <object class="GtkImage" id="unic_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -446,7 +436,6 @@
                                   <object class="GtkImage" id="cpsp_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -478,7 +467,6 @@
                                   <object class="GtkImage" id="case_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -532,7 +520,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -555,7 +542,6 @@
                                   <object class="GtkImage" id="lnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -579,7 +565,6 @@
                                   <object class="GtkImage" id="onum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -625,7 +610,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -648,7 +632,6 @@
                                   <object class="GtkImage" id="pnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -672,7 +655,6 @@
                                   <object class="GtkImage" id="tnum_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -718,7 +700,6 @@
                                     <property name="visible">1</property>
                                     <property name="opacity">0</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -741,7 +722,6 @@
                                   <object class="GtkImage" id="frac_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -765,7 +745,6 @@
                                   <object class="GtkImage" id="afrc_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -810,7 +789,6 @@
                                   <object class="GtkImage" id="zero_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -842,7 +820,6 @@
                                   <object class="GtkImage" id="nalt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -874,7 +851,6 @@
                                   <object class="GtkImage" id="sinf_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -927,7 +903,6 @@
                                   <object class="GtkImage" id="swsh_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -959,7 +934,6 @@
                                   <object class="GtkImage" id="cswh_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -991,7 +965,6 @@
                                   <object class="GtkImage" id="locl_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1023,7 +996,6 @@
                                   <object class="GtkImage" id="calt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1055,7 +1027,6 @@
                                   <object class="GtkImage" id="hist_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1087,7 +1058,6 @@
                                   <object class="GtkImage" id="salt_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1119,7 +1089,6 @@
                                   <object class="GtkImage" id="titl_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1151,7 +1120,6 @@
                                   <object class="GtkImage" id="rand_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1183,7 +1151,6 @@
                                   <object class="GtkImage" id="subs_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1215,7 +1182,6 @@
                                   <object class="GtkImage" id="sups_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1268,7 +1234,6 @@
                                   <object class="GtkImage" id="init_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1300,7 +1265,6 @@
                                   <object class="GtkImage" id="medi_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1332,7 +1296,6 @@
                                   <object class="GtkImage" id="fina_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1364,7 +1327,6 @@
                                   <object class="GtkImage" id="isol_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1417,7 +1379,6 @@
                                   <object class="GtkImage" id="ss01_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1449,7 +1410,6 @@
                                   <object class="GtkImage" id="ss02_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1481,7 +1441,6 @@
                                   <object class="GtkImage" id="ss03_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1513,7 +1472,6 @@
                                   <object class="GtkImage" id="ss04_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
                                   </object>
                                 </child>
                                 <child>
@@ -1545,8 +1503,6 @@
                                   <object class="GtkImage" id="ss05_pres">
                                     <property name="visible">1</property>
                                     <property name="icon-name">object-select-symbolic</property>
-                                    <property name="icon-size">1</property>
-                                  </object>
                                 </child>
                                 <child>
                                   <object class="GtkCheckButton" id="ss05_dflt">
diff --git a/demos/gtk-demo/gtkfishbowl.c b/demos/gtk-demo/gtkfishbowl.c
index 5ba6f86..88056fb 100644
--- a/demos/gtk-demo/gtkfishbowl.c
+++ b/demos/gtk-demo/gtkfishbowl.c
@@ -405,7 +405,7 @@ gtk_fishbowl_set_count (GtkFishbowl *fishbowl,
       GtkWidget *new_widget;
         
       new_widget = gtk_image_new_from_icon_name (get_random_icon_name (gtk_icon_theme_get_default ()));
-      gtk_image_set_icon_size (GTK_IMAGE (new_widget), GTK_ICON_SIZE_DIALOG);
+      gtk_image_set_icon_size (GTK_IMAGE (new_widget), GTK_ICON_SIZE_LARGE);
       gtk_widget_show (new_widget);
       gtk_container_add (GTK_CONTAINER (fishbowl), new_widget);
     }
diff --git a/demos/gtk-demo/images.c b/demos/gtk-demo/images.c
index eec90a9..c4e32be 100644
--- a/demos/gtk-demo/images.c
+++ b/demos/gtk-demo/images.c
@@ -363,7 +363,7 @@ do_images (GtkWidget *do_widget)
       gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE);
 
       image = gtk_image_new_from_icon_name ("gtk3-demo");
-      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
       gtk_container_add (GTK_CONTAINER (frame), image);
 
@@ -400,7 +400,7 @@ do_images (GtkWidget *do_widget)
 
       gicon = g_themed_icon_new_with_default_fallbacks ("battery-caution-charging-symbolic");
       image = gtk_image_new_from_gicon (gicon);
-      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
 
       gtk_container_add (GTK_CONTAINER (frame), image);
 
diff --git a/demos/gtk-demo/listbox.c b/demos/gtk-demo/listbox.c
index a67dac7..22d1ac7 100644
--- a/demos/gtk-demo/listbox.c
+++ b/demos/gtk-demo/listbox.c
@@ -199,7 +199,7 @@ gtk_message_row_update (GtkMessageRow *row)
   if (strcmp (priv->message->sender_nick, "@GTKtoolkit") == 0)
     {
       gtk_image_set_from_icon_name (priv->avatar_image, "gtk3-demo");
-      gtk_image_set_icon_size (priv->avatar_image, GTK_ICON_SIZE_DND);
+      gtk_image_set_icon_size (priv->avatar_image, GTK_ICON_SIZE_LARGE);
     }
   else
     gtk_image_set_from_pixbuf (priv->avatar_image, avatar_pixbuf_other);
diff --git a/demos/gtk-demo/revealer.ui b/demos/gtk-demo/revealer.ui
index 7322684..1c0e342 100644
--- a/demos/gtk-demo/revealer.ui
+++ b/demos/gtk-demo/revealer.ui
@@ -19,7 +19,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -37,7 +37,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -55,7 +55,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -72,7 +72,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -90,7 +90,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -108,7 +108,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -126,7 +126,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -143,7 +143,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
@@ -161,7 +161,7 @@
               <object class="GtkImage">
                 <property name="visible">1</property>
                 <property name="icon-name">face-cool-symbolic</property>
-                <property name="icon-size">6</property>
+                <property name="icon-size">large</property>
               </object>
             </child>
           </object>
diff --git a/demos/gtk-demo/toolpalette.c b/demos/gtk-demo/toolpalette.c
index da6dfa2..5adfca7 100644
--- a/demos/gtk-demo/toolpalette.c
+++ b/demos/gtk-demo/toolpalette.c
@@ -43,7 +43,7 @@ canvas_item_new (GtkWidget     *widget,
 
   icon_name = gtk_tool_button_get_icon_name (button);
   icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
-  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &width, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &width, NULL);
   pixbuf = gtk_icon_theme_load_icon (icon_theme,
                                      icon_name,
                                      width,
diff --git a/demos/icon-browser/window.ui b/demos/icon-browser/window.ui
index 3cedca4..2d25faa 100644
--- a/demos/icon-browser/window.ui
+++ b/demos/icon-browser/window.ui
@@ -50,7 +50,6 @@
               <object class="GtkImage" id="search-icon">
                 <property name="visible">True</property>
                 <property name="icon-name">edit-find-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
diff --git a/demos/widget-factory/widget-factory.ui b/demos/widget-factory/widget-factory.ui
index 6752bed..e4517aa 100644
--- a/demos/widget-factory/widget-factory.ui
+++ b/demos/widget-factory/widget-factory.ui
@@ -2056,7 +2056,6 @@ microphone-sensitivity-medium-symbolic</property>
                                           <object class="GtkImage" id="listboxrow3image">
                                             <property name="visible">1</property>
                                             <property name="icon-name">object-select-symbolic</property>
-                                            <property name="icon-size">1</property>
                                             <property name="halign">end</property>
                                             <property name="valign">center</property>
                                             <property name="margin-top">6</property>
@@ -2092,7 +2091,6 @@ microphone-sensitivity-medium-symbolic</property>
                                           <object class="GtkImage">
                                             <property name="visible">1</property>
                                             <property name="icon-name">object-select-symbolic</property>
-                                            <property name="icon-size">1</property>
                                             <property name="halign">end</property>
                                             <property name="valign">center</property>
                                             <property name="margin-top">6</property>
diff --git a/docs/tools/widgets.c b/docs/tools/widgets.c
index b8d9998..49f01cd 100644
--- a/docs/tools/widgets.c
+++ b/docs/tools/widgets.c
@@ -1095,7 +1095,7 @@ create_image (void)
   GtkWidget *vbox;
 
   widget = gtk_image_new_from_icon_name ("applications-graphics");
-  gtk_image_set_icon_size (GTK_IMAGE (widget), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (widget), GTK_ICON_SIZE_LARGE);
   gtk_widget_set_halign (widget, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (widget, GTK_ALIGN_CENTER);
 
diff --git a/examples/application10/window.ui b/examples/application10/window.ui
index 270e129..6c02697 100644
--- a/examples/application10/window.ui
+++ b/examples/application10/window.ui
@@ -43,7 +43,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application7/window.ui b/examples/application7/window.ui
index 8f96f89..d500409 100644
--- a/examples/application7/window.ui
+++ b/examples/application7/window.ui
@@ -29,7 +29,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application8/window.ui b/examples/application8/window.ui
index d2a085a..3e51eb7 100644
--- a/examples/application8/window.ui
+++ b/examples/application8/window.ui
@@ -29,7 +29,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/examples/application9/window.ui b/examples/application9/window.ui
index f58d10c..c36337b 100644
--- a/examples/application9/window.ui
+++ b/examples/application9/window.ui
@@ -46,7 +46,6 @@
                   <object class="GtkImage" id="search-icon">
                     <property name="visible">True</property>
                     <property name="icon-name">edit-find-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
               </object>
diff --git a/gtk/gtkcellrendererpixbuf.c b/gtk/gtkcellrendererpixbuf.c
index e342289..9d57abb 100644
--- a/gtk/gtkcellrendererpixbuf.c
+++ b/gtk/gtkcellrendererpixbuf.c
@@ -103,7 +103,7 @@ gtk_cell_renderer_pixbuf_init (GtkCellRendererPixbuf *cellpixbuf)
   priv = cellpixbuf->priv;
 
   priv->image_def = gtk_image_definition_new_empty ();
-  priv->icon_size = GTK_ICON_SIZE_MENU;
+  priv->icon_size = GTK_ICON_SIZE_INHERIT;
 }
 
 static void
@@ -179,7 +179,7 @@ gtk_cell_renderer_pixbuf_class_init (GtkCellRendererPixbufClass *class)
                                                      P_("The GtkIconSize value that specifies the size of 
the rendered icon"),
                                                      0,
                                                      G_MAXUINT,
-                                                     GTK_ICON_SIZE_MENU,
+                                                     GTK_ICON_SIZE_INHERIT,
                                                      GTK_PARAM_READWRITE));
 
   /**
diff --git a/gtk/gtkcellrendererspinner.c b/gtk/gtkcellrendererspinner.c
index 54b1cbd..11b8ff9 100644
--- a/gtk/gtkcellrendererspinner.c
+++ b/gtk/gtkcellrendererspinner.c
@@ -152,7 +152,7 @@ gtk_cell_renderer_spinner_class_init (GtkCellRendererSpinnerClass *klass)
                                    g_param_spec_enum ("size",
                                                       P_("Size"),
                                                       P_("The GtkIconSize value that specifies the size of 
the rendered spinner"),
-                                                      GTK_TYPE_ICON_SIZE, GTK_ICON_SIZE_MENU,
+                                                      GTK_TYPE_ICON_SIZE, GTK_ICON_SIZE_INHERIT,
                                                       G_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
 
 }
@@ -162,7 +162,7 @@ gtk_cell_renderer_spinner_init (GtkCellRendererSpinner *cell)
 {
   cell->priv = gtk_cell_renderer_spinner_get_instance_private (cell);
   cell->priv->pulse = 0;
-  cell->priv->icon_size = GTK_ICON_SIZE_MENU;
+  cell->priv->icon_size = GTK_ICON_SIZE_INHERIT;
 }
 
 /**
diff --git a/gtk/gtkentry.c b/gtk/gtkentry.c
index 222cf28..db1f26a 100644
--- a/gtk/gtkentry.c
+++ b/gtk/gtkentry.c
@@ -7937,8 +7937,6 @@ gtk_entry_set_icon_from_pixbuf (GtkEntry             *entry,
   if (pixbuf)
     {
       _gtk_icon_helper_set_pixbuf (GTK_ICON_HELPER (icon_info->gadget), pixbuf);
-      _gtk_icon_helper_set_icon_size (GTK_ICON_HELPER (icon_info->gadget),
-                                      GTK_ICON_SIZE_MENU);
 
       if (icon_pos == GTK_ENTRY_ICON_PRIMARY)
         {
diff --git a/gtk/gtkenums.h b/gtk/gtkenums.h
index bf3da9f..b0a6529 100644
--- a/gtk/gtkenums.h
+++ b/gtk/gtkenums.h
@@ -175,25 +175,20 @@ typedef enum
 
 /**
  * GtkIconSize:
- * @GTK_ICON_SIZE_INVALID: Invalid size.
- * @GTK_ICON_SIZE_MENU: Size appropriate for menus (16px).
- * @GTK_ICON_SIZE_SMALL_TOOLBAR: Size appropriate for small toolbars (16px).
- * @GTK_ICON_SIZE_LARGE_TOOLBAR: Size appropriate for large toolbars (24px)
- * @GTK_ICON_SIZE_BUTTON: Size appropriate for buttons (16px)
- * @GTK_ICON_SIZE_DND: Size appropriate for drag and drop (32px)
- * @GTK_ICON_SIZE_DIALOG: Size appropriate for dialogs (48px)
+ * @GTK_ICON_SIZE_INHERIT: Keep the size of the parent element
+ * @GTK_ICON_SIZE_NORMAL: Size similar to text size
+ * @GTK_ICON_SIZE_LARGE: Large size, for example in an icon view
  *
- * Built-in stock icon sizes.
+ * Built-in icon sizes.
+ *
+ * Icon sizes default to being inherited. Where they cannot be
+ * inherited, text size is the default.
  */
 typedef enum
 {
-  GTK_ICON_SIZE_INVALID,
-  GTK_ICON_SIZE_MENU,
-  GTK_ICON_SIZE_SMALL_TOOLBAR,
-  GTK_ICON_SIZE_LARGE_TOOLBAR,
-  GTK_ICON_SIZE_BUTTON,
-  GTK_ICON_SIZE_DND,
-  GTK_ICON_SIZE_DIALOG
+  GTK_ICON_SIZE_INHERIT,
+  GTK_ICON_SIZE_NORMAL,
+  GTK_ICON_SIZE_LARGE
 } GtkIconSize;
 
 /**
diff --git a/gtk/gtkiconhelper.c b/gtk/gtkiconhelper.c
index 4740743..bc12abb 100644
--- a/gtk/gtkiconhelper.c
+++ b/gtk/gtkiconhelper.c
@@ -212,7 +212,7 @@ gtk_icon_helper_init (GtkIconHelper *self)
 
   self->priv->def = gtk_image_definition_new_empty ();
 
-  self->priv->icon_size = GTK_ICON_SIZE_INVALID;
+  self->priv->icon_size = GTK_ICON_SIZE_INHERIT;
   self->priv->pixel_size = -1;
   self->priv->rendered_surface_is_symbolic = FALSE;
 }
@@ -230,7 +230,7 @@ ensure_icon_size (GtkIconHelper *self,
     }
   else if (!gtk_icon_size_lookup (self->priv->icon_size, &width, &height))
     {
-      if (self->priv->icon_size == GTK_ICON_SIZE_INVALID)
+      if (self->priv->icon_size == GTK_ICON_SIZE_INHERIT)
         {
           width = height = 0;
         }
@@ -334,7 +334,7 @@ get_pixbuf_size (GtkIconHelper   *self,
 
   if (self->priv->force_scale_pixbuf &&
       (self->priv->pixel_size != -1 ||
-       self->priv->icon_size != GTK_ICON_SIZE_INVALID))
+       self->priv->icon_size != GTK_ICON_SIZE_INHERIT))
     {
       ensure_icon_size (self, &width, &height);
 
@@ -644,7 +644,7 @@ _gtk_icon_helper_get_size (GtkIconHelper *self,
         {
           get_surface_size (self, self->priv->rendered_surface, &width, &height);
         }
-      else if (self->priv->icon_size != GTK_ICON_SIZE_INVALID)
+      else if (self->priv->icon_size != GTK_ICON_SIZE_INHERIT)
         {
           ensure_icon_size (self, &width, &height);
         }
diff --git a/gtk/gtkiconthemeprivate.h b/gtk/gtkiconthemeprivate.h
index 0144134..bf1a7a3 100644
--- a/gtk/gtkiconthemeprivate.h
+++ b/gtk/gtkiconthemeprivate.h
@@ -19,6 +19,7 @@
 #define __GTK_ICON_THEME_PRIVATE_H__
 
 #include <gtk/gtkicontheme.h>
+#include <gtk/gtkcssnodeprivate.h>
 #include <gtk/gtkcssstyleprivate.h>
 
 void        gtk_icon_theme_lookup_symbolic_colors       (GtkCssStyle    *style,
diff --git a/gtk/gtkimage.c b/gtk/gtkimage.c
index 6510ed5..47dedeb 100644
--- a/gtk/gtkimage.c
+++ b/gtk/gtkimage.c
@@ -141,7 +141,7 @@ struct _GtkImagePrivate
 };
 
 
-#define DEFAULT_ICON_SIZE GTK_ICON_SIZE_BUTTON
+#define DEFAULT_ICON_SIZE GTK_ICON_SIZE_INHERIT
 static void gtk_image_snapshot             (GtkWidget    *widget,
                                             GtkSnapshot  *snapshot);
 static void gtk_image_size_allocate        (GtkWidget    *widget,
@@ -1642,7 +1642,7 @@ gtk_image_set_icon_size (GtkImage    *image,
 GtkIconSize
 gtk_image_get_icon_size (GtkImage *image)
 {
-  g_return_val_if_fail (GTK_IS_IMAGE (image), GTK_ICON_SIZE_INVALID);
+  g_return_val_if_fail (GTK_IS_IMAGE (image), GTK_ICON_SIZE_INHERIT);
 
   return _gtk_icon_helper_get_icon_size (image->priv->icon_helper);
 }
diff --git a/gtk/gtkmountoperation.c b/gtk/gtkmountoperation.c
index c200213..ad55af2 100644
--- a/gtk/gtkmountoperation.c
+++ b/gtk/gtkmountoperation.c
@@ -550,7 +550,7 @@ gtk_mount_operation_ask_password_do_gtk (GtkMountOperation *operation,
   gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE);
 
   icon = gtk_image_new_from_icon_name ("dialog-password");
-  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_LARGE);
 
   gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (icon, GTK_ALIGN_START);
diff --git a/gtk/gtkprintbackend.c b/gtk/gtkprintbackend.c
index 10a2782..9012dca 100644
--- a/gtk/gtkprintbackend.c
+++ b/gtk/gtkprintbackend.c
@@ -770,7 +770,7 @@ request_password (GtkPrintBackend  *backend,
 
   /* Left */
   icon = gtk_image_new_from_icon_name ("dialog-password-symbolic");
-  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (icon), GTK_ICON_SIZE_LARGE);
   gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (icon, GTK_ALIGN_START);
   g_object_set (icon, "margin", 12, NULL);
diff --git a/gtk/gtkprintunixdialog.c b/gtk/gtkprintunixdialog.c
index 3618e7b..4d06655 100644
--- a/gtk/gtkprintunixdialog.c
+++ b/gtk/gtkprintunixdialog.c
@@ -2319,7 +2319,7 @@ gtk_print_unix_dialog_style_updated (GtkWidget *widget)
       gint size;
       gfloat scale;
 
-      gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &size, NULL);
+      gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &size, NULL);
       scale = size / 48.0;
 
       gtk_widget_set_size_request (priv->collate_image,
diff --git a/gtk/gtkrecentchooserdefault.c b/gtk/gtkrecentchooserdefault.c
index f6c74da..5791706 100644
--- a/gtk/gtkrecentchooserdefault.c
+++ b/gtk/gtkrecentchooserdefault.c
@@ -78,8 +78,6 @@ typedef struct
   gulong manager_changed_id;
   guint local_manager : 1;
 
-  gint icon_size;
-
   /* RecentChooser properties */
   gint limit;
   GtkRecentSortType sort_type;
@@ -355,7 +353,6 @@ _gtk_recent_chooser_default_init (GtkRecentChooserDefault *impl)
   priv->select_multiple = FALSE;
   priv->local_only = TRUE;
   
-  priv->icon_size = FALLBACK_ICON_SIZE;
   priv->icon_theme = NULL;
   
   priv->current_filter = NULL;
@@ -800,9 +797,6 @@ reload_recent_items (GtkRecentChooserDefault *impl)
   if (!impl->priv->icon_theme)
     impl->priv->icon_theme = get_icon_theme_for_widget (widget);
 
-  impl->priv->icon_size = get_icon_size_for_widget (widget,
-                                             GTK_ICON_SIZE_BUTTON);
-
   if (!impl->priv->limit_set)
     impl->priv->limit = DEFAULT_RECENT_FILES_LIMIT;
 
@@ -836,8 +830,8 @@ set_default_size (GtkRecentChooserDefault *impl)
   /* Size based on characters and the icon size */
   gtk_style_context_get (context, "font-size", &font_size, NULL);
 
-  width = impl->priv->icon_size + font_size * NUM_CHARS + 0.5;
-  height = (impl->priv->icon_size + font_size) * NUM_LINES + 0.5;
+  width = 16 + font_size * NUM_CHARS + 0.5;
+  height = (16 + font_size) * NUM_LINES + 0.5;
 
   /* Use at least the requisition size... */
   gtk_widget_get_preferred_size (widget, &req, NULL);
@@ -1362,7 +1356,7 @@ get_drag_pixbuf (GtkRecentChooserDefault *impl)
   if (!info)
     return NULL;
 
-  size = get_icon_size_for_widget (GTK_WIDGET (impl), GTK_ICON_SIZE_DND);
+  size = get_icon_size_for_widget (GTK_WIDGET (impl), GTK_ICON_SIZE_NORMAL);
 
   retval = gtk_recent_info_get_icon (info, size);
   gtk_recent_info_unref (info);
diff --git a/gtk/gtktoolbutton.c b/gtk/gtktoolbutton.c
index 384ef23..6161029 100644
--- a/gtk/gtktoolbutton.c
+++ b/gtk/gtktoolbutton.c
@@ -458,13 +458,6 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
       if (button->priv->icon_widget)
        {
          icon = button->priv->icon_widget;
-
-         if (GTK_IS_IMAGE (icon))
-           {
-             g_object_set (button->priv->icon_widget,
-                           "icon-size", GTK_ICON_SIZE_SMALL_TOOLBAR,
-                           NULL);
-           }
        }
       else if (button->priv->icon_name)
        {
@@ -733,7 +726,7 @@ clone_image_menu_size (GtkImage *image)
     {
       gint width, height;
       
-      if (gtk_icon_size_lookup (GTK_ICON_SIZE_MENU, &width, &height))
+      if (gtk_icon_size_lookup (GTK_ICON_SIZE_NORMAL, &width, &height))
        {
          GdkPixbuf *src_pixbuf, *dest_pixbuf;
          GtkWidget *cloned_image;
diff --git a/gtk/inspector/general.ui b/gtk/inspector/general.ui
index 527d63e..7fc10ac 100644
--- a/gtk/inspector/general.ui
+++ b/gtk/inspector/general.ui
@@ -416,7 +416,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                           </object>
                           <packing>
                             <property name="expand">True</property>
@@ -450,7 +449,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                           </object>
                           <packing>
                             <property name="expand">True</property>
diff --git a/gtk/inspector/misc-info.ui b/gtk/inspector/misc-info.ui
index a5bc70d..fa45682 100644
--- a/gtk/inspector/misc-info.ui
+++ b/gtk/inspector/misc-info.ui
@@ -487,7 +487,6 @@
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
                             <property name="icon-name">object-select-symbolic</property>
-                            <property name="icon-size">1</property>
                           </object>
                         </child>
                       </object>
@@ -696,7 +695,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -732,7 +730,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -768,7 +765,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
@@ -804,7 +800,6 @@
                             <property name="visible">true</property>
                             <property name="halign">end</property>
                             <property name="valign">baseline</property>
-                            <property name="icon-size">1</property>
                             <property name="icon-name">object-select-symbolic</property>
                           </object>
                         </child>
diff --git a/gtk/ui/gtkfilechooserbutton.ui b/gtk/ui/gtkfilechooserbutton.ui
index 0c80df2..56642b7 100644
--- a/gtk/ui/gtkfilechooserbutton.ui
+++ b/gtk/ui/gtkfilechooserbutton.ui
@@ -52,7 +52,6 @@
               <object class="GtkImage" id="open_file_icon">
                 <property name="visible">1</property>
                 <property name="icon-name">document-open-symbolic</property>
-                <property name="icon-size">1</property>
                 <property name="use-fallback">1</property>
                 <property name="valign">baseline</property>
               </object>
diff --git a/gtk/ui/gtkpagesetupunixdialog.ui b/gtk/ui/gtkpagesetupunixdialog.ui
index e273f64..b613c91 100644
--- a/gtk/ui/gtkpagesetupunixdialog.ui
+++ b/gtk/ui/gtkpagesetupunixdialog.ui
@@ -143,7 +143,6 @@
                       <object class="GtkImage" id="image1">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-portrait</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -179,7 +178,6 @@
                       <object class="GtkImage" id="image2">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-reverse-portrait</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -215,7 +213,6 @@
                       <object class="GtkImage" id="image3">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-landscape</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
@@ -250,7 +247,6 @@
                       <object class="GtkImage" id="image4">
                         <property name="visible">1</property>
                         <property name="icon-name">gtk-orientation-reverse-landscape</property>
-                        <property name="icon-size">3</property>
                       </object>
                     </child>
                     <child>
diff --git a/gtk/ui/gtkpathbar.ui b/gtk/ui/gtkpathbar.ui
index b9fefc7..182405f 100644
--- a/gtk/ui/gtkpathbar.ui
+++ b/gtk/ui/gtkpathbar.ui
@@ -19,7 +19,6 @@
       <object class="GtkImage">
         <property name="visible">1</property>
         <property name="icon-name">pan-end-symbolic</property>
-        <property name="icon-size">1</property>
       </object>
     </child>
     <style>
@@ -44,7 +43,6 @@
       <object class="GtkImage">
         <property name="visible">1</property>
         <property name="icon-name">pan-start-symbolic</property>
-        <property name="icon-size">1</property>
       </object>
     </child>
     <style>
diff --git a/gtk/ui/gtkplacesviewrow.ui b/gtk/ui/gtkplacesviewrow.ui
index cce5732..322a8ba 100644
--- a/gtk/ui/gtkplacesviewrow.ui
+++ b/gtk/ui/gtkplacesviewrow.ui
@@ -74,7 +74,6 @@
                       <object class="GtkImage" id="eject_icon">
                         <property name="visible">1</property>
                         <property name="icon-name">media-eject-symbolic</property>
-                        <property name="icon-size">1</property>
                       </object>
                     </child>
                     <style>
diff --git a/gtk/ui/gtkprintunixdialog.ui b/gtk/ui/gtkprintunixdialog.ui
index 95247d0..1572d72 100644
--- a/gtk/ui/gtkprintunixdialog.ui
+++ b/gtk/ui/gtkprintunixdialog.ui
@@ -1319,7 +1319,6 @@
                   <object class="GtkImage" id="image1">
                     <property name="visible">1</property>
                     <property name="icon-name">dialog-warning-symbolic</property>
-                    <property name="icon-size">1</property>
                   </object>
                 </child>
                 <child>
diff --git a/gtk/ui/gtksearchbar.ui b/gtk/ui/gtksearchbar.ui
index 7b520bd..f2b1bb7 100644
--- a/gtk/ui/gtksearchbar.ui
+++ b/gtk/ui/gtksearchbar.ui
@@ -50,7 +50,6 @@
                     <child>
                       <object class="GtkImage" id="close_image">
                         <property name="visible">1</property>
-                        <property name="icon-size">1</property>
                         <property name="icon-name">window-close-symbolic</property>
                       </object>
                     </child>
diff --git a/tests/dialog.ui b/tests/dialog.ui
index 58d3f34..8c7a97f 100644
--- a/tests/dialog.ui
+++ b/tests/dialog.ui
@@ -34,7 +34,6 @@
             <child>
               <object class="GtkImage" id="back_icon">
                 <property name="visible">True</property>
-                <property name="icon_size">1</property>
               </object>
             </child>
           </object>
diff --git a/tests/selectionmode.ui b/tests/selectionmode.ui
index e5799e3..19f69f4 100644
--- a/tests/selectionmode.ui
+++ b/tests/selectionmode.ui
@@ -28,7 +28,6 @@
               <object class="GtkImage">
                 <property name="visible">True</property>
                 <property name="icon-name">emblem-system-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
@@ -68,7 +67,6 @@
                       <object class="GtkImage">
                         <property name="visible">True</property>
                         <property name="icon-name">pan-down-symbolic</property>
-                        <property name="icon-size">1</property>
                       </object>
                     </child>
                   </object>
@@ -91,7 +89,6 @@
               <object class="GtkImage">
                 <property name="visible">True</property>
                 <property name="icon-name">object-select-symbolic</property>
-                <property name="icon-size">1</property>
               </object>
             </child>
           </object>
diff --git a/tests/testdialog.c b/tests/testdialog.c
index 5350b47..c705346 100644
--- a/tests/testdialog.c
+++ b/tests/testdialog.c
@@ -34,7 +34,7 @@ show_message_dialog1a (GtkWindow *parent)
                                                "The system network services are not compatible with this 
version."));
 
   image = gtk_image_new_from_icon_name ("computer-fail");
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_widget_show (image);
 
   gtk_dialog_run (GTK_DIALOG (dialog));
diff --git a/tests/testdnd2.c b/tests/testdnd2.c
index 1a892dd..d0023fa 100644
--- a/tests/testdnd2.c
+++ b/tests/testdnd2.c
@@ -12,7 +12,7 @@ get_image_pixbuf (GtkImage *image)
       return g_object_ref (gtk_image_get_pixbuf (image));
     case GTK_IMAGE_ICON_NAME:
       icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (image)));
-      gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &width, NULL);
+      gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE, &width, NULL);
       return gtk_icon_theme_load_icon (icon_theme,
                                        gtk_image_get_icon_name (image),
                                        width,
@@ -222,7 +222,7 @@ make_image (const gchar *icon_name, int hotspot)
   GtkWidget *image, *ebox;
 
   image = gtk_image_new_from_icon_name (icon_name);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   ebox = gtk_event_box_new ();
 
   gtk_drag_source_set (ebox, GDK_BUTTON1_MASK, NULL, 0, GDK_ACTION_COPY);
@@ -248,7 +248,7 @@ make_image2 (const gchar *icon_name, int hotspot)
   GtkWidget *image, *ebox;
 
   image = gtk_image_new_from_icon_name (icon_name);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   ebox = gtk_event_box_new ();
 
   gtk_drag_source_set (ebox, GDK_BUTTON1_MASK, NULL, 0, GDK_ACTION_COPY);
diff --git a/tests/testflowbox.c b/tests/testflowbox.c
index 53a6c5f..926fdbb 100644
--- a/tests/testflowbox.c
+++ b/tests/testflowbox.c
@@ -178,7 +178,7 @@ populate_flowbox_images (GtkFlowBox *flowbox)
       gtk_widget_set_hexpand (widget, TRUE);
 
       image = gtk_image_new_from_icon_name ("face-wink");
-      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+      gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
       gtk_widget_set_hexpand (image, TRUE);
       gtk_image_set_pixel_size (GTK_IMAGE (image), 256);
 
diff --git a/tests/testgiconpixbuf.c b/tests/testgiconpixbuf.c
index 6d7f840..e10179b 100644
--- a/tests/testgiconpixbuf.c
+++ b/tests/testgiconpixbuf.c
@@ -39,7 +39,7 @@ main (int argc,
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE);
 
   image = gtk_image_new_from_gicon (G_ICON (pixbuf));
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (vbox), image, FALSE, FALSE);
 
   label = gtk_label_new (NULL);
@@ -55,7 +55,7 @@ main (int argc,
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE);
 
   image2 = gtk_image_new_from_gicon (emblemed);
-  gtk_image_set_icon_size (GTK_IMAGE (image2), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image2), GTK_ICON_SIZE_LARGE);
   gtk_box_pack_start (GTK_BOX (vbox), image2, FALSE, FALSE);
 
   label = gtk_label_new (NULL);
diff --git a/tests/testimage.c b/tests/testimage.c
index 03336f6..e612973 100644
--- a/tests/testimage.c
+++ b/tests/testimage.c
@@ -134,10 +134,10 @@ main (int argc, char **argv)
   label = gtk_label_new ("GTK_IMAGE_ICON_NAME");
   gtk_grid_attach (GTK_GRID (grid), label, 0, 4, 1, 1);
   image = gtk_image_new_from_icon_name (icon_name);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 4, 1, 1);
   image = gtk_image_new_from_icon_name (icon_name);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 30);
   gtk_grid_attach (GTK_GRID (grid), image, 2, 4, 1, 1);
 
@@ -145,13 +145,13 @@ main (int argc, char **argv)
   gtk_grid_attach (GTK_GRID (grid), label, 0, 5, 1, 1);
   icon = g_themed_icon_new_with_default_fallbacks ("folder-remote");
   image = gtk_image_new_from_gicon (icon);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   g_object_unref (icon);
   gtk_grid_attach (GTK_GRID (grid), image, 1, 5, 1, 1);
   file = g_file_new_for_path ("apple-red.png");
   icon = g_file_icon_new (file);
   image = gtk_image_new_from_gicon (icon);
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   g_object_unref (icon);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 30);
   gtk_grid_attach (GTK_GRID (grid), image, 2, 5, 1, 1);
diff --git a/tests/testnotebookdnd.c b/tests/testnotebookdnd.c
index 3342c3d..6ac4543 100644
--- a/tests/testnotebookdnd.c
+++ b/tests/testnotebookdnd.c
@@ -96,26 +96,15 @@ on_notebook_drag_begin (GtkWidget      *widget,
                         GdkDragContext *context,
                         gpointer        data)
 {
-  GdkPixbuf *pixbuf;
   guint page_num;
 
   page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (widget));
 
   if (page_num > 2)
     {
-      GtkIconTheme *icon_theme;
-      int width;
-
-      icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
-      gtk_icon_size_lookup (GTK_ICON_SIZE_DND, &width, NULL);
-      pixbuf = gtk_icon_theme_load_icon (icon_theme,
-                                         (page_num % 2) ? "help-browser" : "process-stop",
-                                         width,
-                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK,
-                                         NULL);
-
-      gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
-      g_object_unref (pixbuf);
+      gtk_drag_set_icon_name (context,
+                              (page_num % 2) ? "help-browser" : "process-stop",
+                              0, 0);
     }
 }
 
diff --git a/tests/testtoolbar.c b/tests/testtoolbar.c
index 2dcf8fa..3f9194c 100644
--- a/tests/testtoolbar.c
+++ b/tests/testtoolbar.c
@@ -557,7 +557,7 @@ main (gint argc, gchar **argv)
   gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
   
   image = gtk_image_new_from_icon_name ("dialog-warning");
-  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_DIALOG);
+  gtk_image_set_icon_size (GTK_IMAGE (image), GTK_ICON_SIZE_LARGE);
   item = gtk_tool_item_new ();
   gtk_widget_show (image);
   gtk_container_add (GTK_CONTAINER (item), image);
diff --git a/tests/testverticalcells.c b/tests/testverticalcells.c
index a25abf6..a124c58 100644
--- a/tests/testverticalcells.c
+++ b/tests/testverticalcells.c
@@ -322,7 +322,7 @@ main (gint argc, gchar **argv)
   column = gtk_tree_view_column_new ();
 
   renderer = gtk_cell_renderer_pixbuf_new ();
-  g_object_set (renderer, "stock-size", GTK_ICON_SIZE_DIALOG, NULL);
+  g_object_set (renderer, "stock-size", GTK_ICON_SIZE_LARGE, NULL);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer,
                                       "icon-name", ICON_COLUMN, NULL);
diff --git a/tests/visuals/osd-toolbars.ui b/tests/visuals/osd-toolbars.ui
index 3ac7df6..ac8ae62 100644
--- a/tests/visuals/osd-toolbars.ui
+++ b/tests/visuals/osd-toolbars.ui
@@ -39,7 +39,6 @@
                           <object class="GtkImage" id="camera_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">camera-web-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -52,7 +51,6 @@
                           <object class="GtkImage" id="volume_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">audio-volume-medium-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -65,7 +63,6 @@
                           <object class="GtkImage" id="microphone_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">audio-input-microphone-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -79,7 +76,6 @@
                           <object class="GtkImage" id="bt_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">bluetooth-active-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -125,7 +121,6 @@
                           <object class="GtkImage" id="opt_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">media-optical-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -138,7 +133,6 @@
                           <object class="GtkImage" id="hdd_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">drive-harddisk-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -151,7 +145,6 @@
                           <object class="GtkImage" id="joy_icon">
                             <property name="visible">True</property>
                             <property name="icon_name">input-gaming-symbolic</property>
-                            <property name="icon_size">1</property>
                           </object>
                         </child>
                       </object>
@@ -169,7 +162,6 @@
             <property name="halign">center</property>
             <property name="valign">start</property>
             <property name="margin_top">24</property>
-            <property name="icon_size">1</property>
             <style>
                 <class name="osd"/>
             </style>
diff --git a/testsuite/reftests/gtk-icontheme-sizing.ref.ui b/testsuite/reftests/gtk-icontheme-sizing.ref.ui
index 7e7861d..5f99d6b 100644
--- a/testsuite/reftests/gtk-icontheme-sizing.ref.ui
+++ b/testsuite/reftests/gtk-icontheme-sizing.ref.ui
@@ -11,7 +11,6 @@
         <property name="can_focus">False</property>
         <property name="pixel_size">100</property>
         <property name="icon_name">pan-down-symbolic</property>
-        <property name="icon_size">0</property>
       </object>
     </child>
   </object>
diff --git a/testsuite/reftests/icon-vfuncs.ui b/testsuite/reftests/icon-vfuncs.ui
index 7c0db70..f2f215a 100644
--- a/testsuite/reftests/icon-vfuncs.ui
+++ b/testsuite/reftests/icon-vfuncs.ui
@@ -109,7 +109,6 @@
             <property name="visible">True</property>
             <property name="can_focus">False</property>
             <property name="icon_name">pan-down-symbolic</property>
-            <property name="icon_size">1</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
           </object>
diff --git a/testsuite/reftests/iconview-empty.ref.ui b/testsuite/reftests/iconview-empty.ref.ui
index b312b6b..d89279a 100644
--- a/testsuite/reftests/iconview-empty.ref.ui
+++ b/testsuite/reftests/iconview-empty.ref.ui
@@ -16,7 +16,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -33,7 +32,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -50,7 +48,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -67,7 +64,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -84,7 +80,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -101,7 +96,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -118,7 +112,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -135,7 +128,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">0</property>
             <property name="height-request">0</property>
           </object>
@@ -152,7 +144,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -169,7 +160,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -186,7 +176,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -203,7 +192,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -220,7 +208,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -237,7 +224,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -254,7 +240,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>
@@ -271,7 +256,6 @@
             <property name="can_focus">False</property>
             <property name="halign">center</property>
             <property name="valign">center</property>
-            <property name="icon-size">0</property>
             <property name="width-request">10</property>
             <property name="height-request">10</property>
           </object>


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkicontheme.c b/gtk/gtkicontheme.c
index 8b12c02..1c5d7ed 100644
--- a/gtk/gtkicontheme.c
+++ b/gtk/gtkicontheme.c
@@ -5306,48 +5306,23 @@ typedef struct _IconSize IconSize;
 
 struct _IconSize
 {
-  const char *name;
-
   int width;
   int height;
 };
 
 static const IconSize icon_sizes[] = {
-  [GTK_ICON_SIZE_INVALID] = {
-    .name = NULL,
-    .width = 0,
-    .height = 0,
-  },
-  [GTK_ICON_SIZE_MENU] = {
-    .name = "gtk-menu",
-    .width = 16,
-    .height = 16,
-  },
-  [GTK_ICON_SIZE_BUTTON] = {
-    .name = "gtk-button",
+  [GTK_ICON_SIZE_INHERIT] = {
     .width = 16,
     .height = 16,
   },
-  [GTK_ICON_SIZE_SMALL_TOOLBAR] = {
-    .name = "gtk-small-toolbar",
+  [GTK_ICON_SIZE_NORMAL] = {
     .width = 16,
     .height = 16,
   },
-  [GTK_ICON_SIZE_LARGE_TOOLBAR] = {
-    .name = "gtk-large-toolbar",
-    .width = 24,
-    .height = 24,
-  },
-  [GTK_ICON_SIZE_DND] = {
-    .name = "gtk-dnd",
+  [GTK_ICON_SIZE_LARGE] = {
     .width = 32,
     .height = 32,
-  },
-  [GTK_ICON_SIZE_DIALOG] = {
-    .name = "gtk-dialog",
-    .width = 48,
-    .height = 48,
-  },
+  }
 };
 
 /**
@@ -5357,7 +5332,7 @@ static const IconSize icon_sizes[] = {
  * @height: (out) (optional): location to store icon height
  *
  * Obtains the pixel size of a semantic icon size @size:
  * #GTK_ICON_SIZE_MENU, #GTK_ICON_SIZE_BUTTON, etc.  This function
  * isn’t normally needed, gtk_icon_theme_load_icon() is the usual
  * way to get an icon for rendering, then just look at the size of
  * the rendered pixbuf. The rendered pixbuf may not even correspond to
@@ -5381,9 +5356,6 @@ gtk_icon_size_lookup (GtkIconSize  size,
   if (size >= G_N_ELEMENTS (icon_sizes))
     return FALSE;
 
-  if (size == GTK_ICON_SIZE_INVALID)
-    return FALSE;
-
   if (widthp)
     *widthp = icon_sizes[size].width;
 
@@ -5357,7 +5332,7 @@ static const IconSize icon_sizes[] = {
  *
  * Obtains the pixel size of a semantic icon size @size:
- * #GTK_ICON_SIZE_MENU, #GTK_ICON_SIZE_BUTTON, etc.  This function
+ * #GTK_ICON_SIZE_NORMAL, #GTK_ICON_SIZE_LARGE, etc.  This function
  * isn’t normally needed, gtk_icon_theme_load_icon() is the usual
  * way to get an icon for rendering, then just look at the size of